@@ -6,7 +6,7 @@ from typing import cast
 import autofit as af
 from autoarray.fit import fit as aa_fit
 from autolens.fit import fit
-from autolens.dataset import dataset as d
+from autolens.dataset import imaging
 from autoastro.galaxy import galaxy as g
 from autoastro.hyper import hyper_data as hd
 from autolens.pipeline.phase import imaging
@@ -51,11 +51,8 @@ class Analysis(af.Analysis):
                 hyper_galaxy_image=self.hyper_galaxy_image,
             )
 
-            fit_normal = aa_fit.ImagingFit(
-                image=self.masked_imaging.image,
-                noise_map=self.masked_imaging.noise_map,
-                mask=self.masked_imaging.mask,
-                model_image=self.hyper_model_image,
+            fit_normal = aa_fit.FitImaging(
+                masked_imaging=self.masked_imaging, model_image=self.hyper_model_image
             )
 
             fit_hyper = self.fit_for_hyper_galaxy(
@@ -130,11 +127,12 @@ class Analysis(af.Analysis):
 
         noise_map = noise_map + hyper_noise_map
 
-        return aa_fit.ImagingFit(
-            image=image,
-            noise_map=noise_map,
-            mask=self.masked_imaging.mask,
-            model_image=self.hyper_model_image,
+        masked_imaging = self.masked_imaging.modify_image_and_noise_map(
+            image=image, noise_map=noise_map
+        )
+
+        return aa_fit.FitImaging(
+            masked_imaging=masked_imaging, model_image=self.hyper_model_image
         )
 
     @classmethod
@@ -169,7 +167,7 @@ class HyperGalaxyPhase(HyperPhase):
 
         phase = self.make_hyper_phase()
 
-        masked_imaging = d.MaskedImaging(
+        masked_imaging = imaging.MaskedImaging(
             imaging=dataset,
             mask=results.last.mask,
             psf_shape_2d=dataset.psf.shape_2d,
