@@ -21,14 +21,14 @@ test_name = "tests"
 
 def simulate_integration_image(test_name, pixel_scales, galaxies):
     output_path = (
-        "{}/test_files/simulator/".format(os.path.dirname(os.path.realpath(__file__)))
+        "{}/files/simulator/".format(os.path.dirname(os.path.realpath(__file__)))
         + test_name
         + "/"
     )
     psf_shape_2d = (11, 11)
     image_shape = (150, 150)
 
-    psf = al.kernel.from_gaussian(
+    psf = al.Kernel.from_gaussian(
         shape_2d=psf_shape_2d, pixel_scales=pixel_scales, sigma=pixel_scales
     )
 
@@ -40,7 +40,7 @@ def simulate_integration_image(test_name, pixel_scales, galaxies):
 
     ### Setup as a simulated image_coords and output as a fits for an lens ###
 
-    imaging_simulated = al.SimulatedImagingData.from_tracer(
+    imaging_simulated = al.SimulatedImagingData.from_tracer_and_grid(
         tracer=tracer,
         pixel_scales=pixel_scales,
         exposure_time=100.0,
@@ -118,13 +118,10 @@ class TestPhaseModelMapper:
             os.path.dirname(os.path.realpath(__file__))
         )  # Setup path so we can output the simulated image.
 
-        imaging = al.imaging.from_fits(
-            image_path=path + "/test_files/simulator/" + test_name + "/image.fits",
-            psf_path=path + "/test_files/simulator/" + test_name + "/psf.fits",
-            noise_map_path=path
-            + "/test_files/simulator/"
-            + test_name
-            + "/noise_map.fits",
+        imaging = al.Imaging.from_fits(
+            image_path=path + "/files/simulator/" + test_name + "/image.fits",
+            psf_path=path + "/files/simulator/" + test_name + "/psf.fits",
+            noise_map_path=path + "/files/simulator/" + test_name + "/noise_map.fits",
             real_space_pixel_scales=0.1,
         )
 
@@ -138,7 +135,7 @@ class TestPhaseModelMapper:
             galaxies=dict(
                 lens=al.GalaxyModel(redshift=0.5, sersic=al.lp.EllipticalSersic)
             ),
-            optimizer_class=af.MultiNest,
+            non_linear_class=af.MultiNest,
             phase_name="{}/phase1".format(test_name),
         )
 
@@ -192,13 +189,10 @@ class TestPhaseModelMapper:
             os.path.dirname(os.path.realpath(__file__))
         )  # Setup path so we can output the simulated image.
 
-        imaging = al.imaging.from_fits(
-            image_path=path + "/test_files/simulator/" + test_name + "/image.fits",
-            psf_path=path + "/test_files/simulator/" + test_name + "/psf.fits",
-            noise_map_path=path
-            + "/test_files/simulator/"
-            + test_name
-            + "/noise_map.fits",
+        imaging = al.Imaging.from_fits(
+            image_path=path + "/files/simulator/" + test_name + "/image.fits",
+            psf_path=path + "/files/simulator/" + test_name + "/psf.fits",
+            noise_map_path=path + "/files/simulator/" + test_name + "/noise_map.fits",
             real_space_pixel_scales=0.1,
         )
 
@@ -214,7 +208,7 @@ class TestPhaseModelMapper:
             galaxies=dict(
                 lens=al.GalaxyModel(redshift=0.5, sersic=al.lp.EllipticalSersic)
             ),
-            optimizer_class=af.MultiNest,
+            non_linear_class=af.MultiNest,
             phase_name="{}/phase1".format(name),
         )
 
