@@ -23,13 +23,13 @@ for data_resolution in ["hst_up"]:
         data_resolution=data_resolution,
         psf_shape_2d=(3, 3),
     )
-    mask = al.mask.circular_annular(
+    mask = al.Mask.circular_annular(
         shape=imaging.shape,
         pixel_scales=imaging.pixel_scales,
         inner_radius=inner_radius,
         outer_radius=outer_radius,
     )
-    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask, sub_size=sub_size)
+    masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask, sub_size=sub_size)
 
     print("Deflection angle run times for image type " + data_resolution + "\n")
     print("Number of points = " + str(masked_imaging.grid.sub_shape_1d) + "\n")
@@ -110,5 +110,5 @@ for data_resolution in ["hst_up"]:
     # difference_percent_x_2d = masked_imaging.grid.scaled_array_2d_with_sub_dimensions_from_sub_array_1d(
     #     sub_array_1d=difference_percent_x)
     #
-    # aplt.array(arrays=difference_percent_y_2d)
-    # aplt.array(arrays=difference_percent_x_2d)
+    # aplt.Array(arrays=difference_percent_y_2d)
+    # aplt.Array(arrays=difference_percent_x_2d)
